@@ -7,7 +7,9 @@ class Browser:
     """
     Abstracts the browser features cross-platform
     """
+
     BROSERS = Literal["firefox", "chrome"]
+
     def open(self, url: Optional[str] = None, app_mode=False, incognito=False) -> None:
         """
         performs the open
@@ -21,20 +23,25 @@ class Browser:
 
         os.system(cmd_to_run)
 
-    def open_shell_cmd(self, url: Optional[str] = None, app_mode=False, incognito=False, browser: Optional[BROSERS] = None) -> str:
+    def open_shell_cmd(
+        self,
+        url: Optional[str] = None,
+        app_mode=False,
+        incognito=False,
+        browser: Optional[BROSERS] = None,
+    ) -> str:
         """
         Returns the shell command to open the browser
         """
-        url_expr = ''
+        url_expr = ""
         if url is not None:
             url_expr = f"'{url}'"
 
-        if browser == 'chrome':
+        if browser == "chrome":
             cmd = f" open -a 'Google Chrome' {url_expr}"
         else:
             cmd = f" open -a Firefox {url_expr}"
 
-
         return cmd
 
 
